EXPORTS
    OnigAsciiLowerMap @1 DATA
    OnigDefaultCaseFoldFlag @2 DATA
    OnigDefaultSyntax @3 DATA
    OnigEncAsciiCtypeTable @4 DATA
    OnigEncAsciiToLowerCaseTable @5 DATA
    OnigEncDefaultCharEncoding @6 DATA
    OnigEncISO_8859_1_ToLowerCaseTable @7 DATA
    OnigEncodingASCII @8 DATA
    OnigEncodingBIG5 @9 DATA
    OnigEncodingCP1251 @10 DATA
    OnigEncodingEUC_CN @11 DATA
    OnigEncodingEUC_JP @12 DATA
    OnigEncodingEUC_KR @13 DATA
    OnigEncodingEUC_TW @14 DATA
    OnigEncodingGB18030 @15 DATA
    OnigEncodingISO_8859_1 @16 DATA
    OnigEncodingISO_8859_10 @17 DATA
    OnigEncodingISO_8859_11 @18 DATA
    OnigEncodingISO_8859_13 @19 DATA
    OnigEncodingISO_8859_14 @20 DATA
    OnigEncodingISO_8859_15 @21 DATA
    OnigEncodingISO_8859_16 @22 DATA
    OnigEncodingISO_8859_2 @23 DATA
    OnigEncodingISO_8859_3 @24 DATA
    OnigEncodingISO_8859_4 @25 DATA
    OnigEncodingISO_8859_5 @26 DATA
    OnigEncodingISO_8859_6 @27 DATA
    OnigEncodingISO_8859_7 @28 DATA
    OnigEncodingISO_8859_8 @29 DATA
    OnigEncodingISO_8859_9 @30 DATA
    OnigEncodingKOI8_R @31 DATA
    OnigEncodingSJIS @32 DATA
    OnigEncodingUTF16_BE @33 DATA
    OnigEncodingUTF16_LE @34 DATA
    OnigEncodingUTF32_BE @35 DATA
    OnigEncodingUTF32_LE @36 DATA
    OnigEncodingUTF8 @37 DATA
    OnigSyntaxASIS @38 DATA
    OnigSyntaxEmacs @39 DATA
    OnigSyntaxGnuRegex @40 DATA
    OnigSyntaxGrep @41 DATA
    OnigSyntaxJava @42 DATA
    OnigSyntaxOniguruma @43 DATA
    OnigSyntaxPerl @44 DATA
    OnigSyntaxPerl_NG @45 DATA
    OnigSyntaxPosixBasic @46 DATA
    OnigSyntaxPosixExtended @47 DATA
    OnigSyntaxPython @48 DATA
    OnigSyntaxRuby @49 DATA
    OnigUnicodeFolds1 @50 DATA
    OnigUnicodeFolds2 @51 DATA
    OnigUnicodeFolds3 @52 DATA
    __gcc_deregister_frame @53
    __gcc_register_frame @54
    onig_add_end_call @55
    onig_builtin_cmp @56
    onig_builtin_count @57
    onig_builtin_error @58
    onig_builtin_fail @59
    onig_builtin_max @60
    onig_builtin_mismatch @61
    onig_builtin_skip @62
    onig_builtin_total_count @63
    onig_callout_tag_is_exist_at_callout_num @64
    onig_callout_tag_table_free @65
    onig_capture_tree_traverse @66
    onig_check_callout_data_and_clear_old_values @67
    onig_codes_byte_at @68
    onig_codes_cmp @69
    onig_compile @70
    onig_copy_encoding @71
    onig_copy_syntax @72
    onig_copyright @73
    onig_detect_can_be_slow_pattern @74
    onig_end @75
    onig_error_code_to_format @76
    onig_error_code_to_str @77
    onig_ext_set_pattern @78
    onig_foreach_name @79
    onig_free @80
    onig_free_body @81
    onig_free_match_param @82
    onig_free_match_param_content @83
    onig_free_reg_callout_list @84
    onig_get_arg_by_callout_args @85
    onig_get_args_num_by_callout_args @86
    onig_get_callback_each_match @87
    onig_get_callout_data @88
    onig_get_callout_data_by_callout_args @89
    onig_get_callout_data_by_callout_args_self @90
    onig_get_callout_data_by_callout_args_self_dont_clear_old @91
    onig_get_callout_data_by_tag @92
    onig_get_callout_data_by_tag_dont_clear_old @93
    onig_get_callout_data_dont_clear_old @94
    onig_get_callout_end_func_by_name_id @95
    onig_get_callout_in_by_callout_args @96
    onig_get_callout_in_by_name_id @97
    onig_get_callout_name_by_name_id @98
    onig_get_callout_num_by_callout_args @99
    onig_get_callout_num_by_tag @100
    onig_get_callout_start_func @101
    onig_get_callout_start_func_by_name_id @102
    onig_get_callout_tag_end @103
    onig_get_callout_tag_start @104
    onig_get_callout_type_by_name_id @105
    onig_get_capture_range_in_callout @106
    onig_get_capture_tree @107
    onig_get_case_fold_flag @108
    onig_get_contents_by_callout_args @109
    onig_get_contents_end_by_callout_args @110
    onig_get_current_by_callout_args @111
    onig_get_default_case_fold_flag @112
    onig_get_encoding @113
    onig_get_match_stack_limit_size @114
    onig_get_name_id_by_callout_args @115
    onig_get_options @116
    onig_get_parse_depth_limit @117
    onig_get_passed_args_num_by_callout_args @118
    onig_get_progress_callout @119
    onig_get_regex_by_callout_args @120
    onig_get_regex_ext @121
    onig_get_retraction_callout @122
    onig_get_retry_counter_by_callout_args @123
    onig_get_retry_limit_in_match @124
    onig_get_retry_limit_in_search @125
    onig_get_right_range_by_callout_args @126
    onig_get_start_by_callout_args @127
    onig_get_string_by_callout_args @128
    onig_get_string_end_by_callout_args @129
    onig_get_subexp_call_limit_in_search @130
    onig_get_subexp_call_max_nest_level @131
    onig_get_syntax @132
    onig_get_syntax_behavior @133
    onig_get_syntax_op @134
    onig_get_syntax_op2 @135
    onig_get_syntax_options @136
    onig_get_used_stack_size_in_callout @137
    onig_global_callout_names_free @138
    onig_init @139
    onig_init_for_match_at @140
    onig_initialize @141
    onig_initialize_encoding @142
    onig_initialize_match_param @143
    onig_is_code_in_cc @144
    onig_is_code_in_cc_len @145
    onig_is_error_code_needs_param @146
    onig_is_in_code_range @147
    onig_match @148
    onig_match_with_param @149
    onig_name_to_backref_number @150
    onig_name_to_group_numbers @151
    onig_names_free @152
    onig_new @153
    onig_new_cclass_with_code_list @154
    onig_new_deluxe @155
    onig_new_match_param @156
    onig_new_without_alloc @157
    onig_node_copy @158
    onig_node_free @159
    onig_node_new_alt @160
    onig_node_new_bag @161
    onig_node_new_list @162
    onig_node_new_str @163
    onig_node_reset_empty @164
    onig_node_reset_fail @165
    onig_node_str_cat @166
    onig_node_str_clear @167
    onig_node_str_set @168
    onig_noname_group_capture_is_active @169
    onig_null_warn @170
    onig_number_of_capture_histories @171
    onig_number_of_captures @172
    onig_number_of_names @173
    onig_parse_tree @174
    onig_positive_int_multiply @175
    onig_reduce_nested_quantifier @176
    onig_reg_callout_list_at @177
    onig_reg_init @178
    onig_region_clear @179
    onig_region_copy @180
    onig_region_free @181
    onig_region_init @182
    onig_region_new @183
    onig_region_resize @184
    onig_region_set @185
    onig_regset_add @186
    onig_regset_free @187
    onig_regset_get_regex @188
    onig_regset_get_region @189
    onig_regset_new @190
    onig_regset_number_of_regex @191
    onig_regset_replace @192
    onig_regset_search @193
    onig_regset_search_with_param @194
    onig_renumber_name_table @195
    onig_scan @196
    onig_scan_env_set_error_string @197
    onig_search @198
    onig_search_with_param @199
    onig_set_callback_each_match @200
    onig_set_callout_data @201
    onig_set_callout_data_by_callout_args @202
    onig_set_callout_data_by_callout_args_self @203
    onig_set_callout_data_by_tag @204
    onig_set_callout_of_name @205
    onig_set_callout_user_data_of_match_param @206
    onig_set_capture_num_limit @207
    onig_set_default_case_fold_flag @208
    onig_set_default_syntax @209
    onig_set_match_stack_limit_size @210
    onig_set_match_stack_limit_size_of_match_param @211
    onig_set_meta_char @212
    onig_set_parse_depth_limit @213
    onig_set_progress_callout @214
    onig_set_progress_callout_of_match_param @215
    onig_set_retraction_callout @216
    onig_set_retraction_callout_of_match_param @217
    onig_set_retry_limit_in_match @218
    onig_set_retry_limit_in_match_of_match_param @219
    onig_set_retry_limit_in_search @220
    onig_set_retry_limit_in_search_of_match_param @221
    onig_set_subexp_call_limit_in_search @222
    onig_set_subexp_call_max_nest_level @223
    onig_set_syntax_behavior @224
    onig_set_syntax_op @225
    onig_set_syntax_op2 @226
    onig_set_syntax_options @227
    onig_set_verb_warn_func @228
    onig_set_warn_func @229
    onig_setup_builtin_monitors_by_ascii_encoded_name @230
    onig_snprintf_with_pattern @231
    onig_st_add_direct @232
    onig_st_cleanup_safe @233
    onig_st_copy @234
    onig_st_delete @235
    onig_st_delete_safe @236
    onig_st_foreach @237
    onig_st_free_table @238
    onig_st_init_callout_name_table_with_size @239
    onig_st_init_numtable @240
    onig_st_init_numtable_with_size @241
    onig_st_init_strend_table_with_size @242
    onig_st_init_strtable @243
    onig_st_init_strtable_with_size @244
    onig_st_init_table @245
    onig_st_init_table_with_size @246
    onig_st_insert @247
    onig_st_insert_strend @248
    onig_st_lookup @249
    onig_st_lookup_callout_name_table @250
    onig_st_lookup_strend @251
    onig_strcpy @252
    onig_strncmp @253
    onig_unicode_define_user_property @254
    onig_version @255
    onig_warning @256
    onigenc_always_false_is_allowed_reverse_match @257
    onigenc_always_true_is_allowed_reverse_match @258
    onigenc_always_true_is_valid_mbc_string @259
    onigenc_apply_all_case_fold_with_map @260
    onigenc_ascii_apply_all_case_fold @261
    onigenc_ascii_get_case_fold_codes_by_str @262
    onigenc_ascii_mbc_case_fold @263
    onigenc_egcb_is_break_position @264
    onigenc_end @265
    onigenc_euc_jp_lookup_property_name @266
    onigenc_get_case_fold_codes_by_str_with_map @267
    onigenc_get_default_encoding @268
    onigenc_get_left_adjust_char_head @269
    onigenc_get_prev_char_head @270
    onigenc_get_right_adjust_char_head @271
    onigenc_get_right_adjust_char_head_with_prev @272
    onigenc_init @273
    onigenc_is_mbc_newline_0x0a @274
    onigenc_is_mbc_word_ascii @275
    onigenc_is_valid_mbc_string @276
    onigenc_length_check_is_valid_mbc_string @277
    onigenc_mb2_code_to_mbc @278
    onigenc_mb2_is_code_ctype @279
    onigenc_mb4_code_to_mbc @280
    onigenc_mb4_is_code_ctype @281
    onigenc_mbn_mbc_case_fold @282
    onigenc_mbn_mbc_to_code @283
    onigenc_minimum_property_name_to_ctype @284
    onigenc_not_support_get_ctype_code_range @285
    onigenc_set_default_caseconv_table @286
    onigenc_set_default_encoding @287
    onigenc_single_byte_code_to_mbc @288
    onigenc_single_byte_code_to_mbclen @289
    onigenc_single_byte_left_adjust_char_head @290
    onigenc_single_byte_mbc_enc_len @291
    onigenc_single_byte_mbc_to_code @292
    onigenc_sjis_lookup_property_name @293
    onigenc_step @294
    onigenc_step_back @295
    onigenc_str_bytelen_null @296
    onigenc_strdup @297
    onigenc_strlen @298
    onigenc_strlen_null @299
    onigenc_unicode_apply_all_case_fold @300
    onigenc_unicode_ctype_code_range @301
    onigenc_unicode_fold1_key @302
    onigenc_unicode_fold2_key @303
    onigenc_unicode_fold3_key @304
    onigenc_unicode_get_case_fold_codes_by_str @305
    onigenc_unicode_is_code_ctype @306
    onigenc_unicode_mbc_case_fold @307
    onigenc_unicode_property_name_to_ctype @308
    onigenc_unicode_unfold_key @309
    onigenc_utf16_32_get_ctype_code_range @310
    onigenc_wb_is_break_position @311
    onigenc_with_ascii_strncmp @312
    re_adjust_startpos @313
    re_alloc_pattern @314
    re_compile_pattern @315
    re_free_pattern @316
    re_free_registers @317
    re_match @318
    re_mbcinit @319
    re_search @320
    re_set_casetable @321
